/*---------------------------------------------------------------------------*
 *
 * Project:	fXPlayMidi
 *
 * $RCSfile: fmAlbum_cb.c,v $
 * $Date: 1997/09/14 01:37:27 $
 * $Author: klmcw $
 * $Revision: 1.5 $
 *
 *---------------------------------------------------------------------------*
 * $Log: fmAlbum_cb.c,v $
 * Revision 1.5  1997/09/14 01:37:27  klmcw
 * Added support for H and V player forms.
 * Because of the introduction of these forms, there could be 3 top level forms!
 * The detection of which one is the _true_ top level form is done through
 * App->fmFirst. This is used by several callbacks so that the right thing is done.
 * For instance, if the HPlayer is the fmFirst, when Exit is hit on the fmAlbum
 * form, just dismiss the form, do not exit the app.
 *
 * Revision 1.4  1997/04/26 11:42:50  klmcw
 * Added fmAbout.
 *
 * Revision 1.3  1997/04/26 07:36:25  klmcw
 * Made 0.86 changes to fl_show_question calls.
 *
 * Revision 1.2  1996/03/09 08:22:27  klmcw
 * Added firsttime special case to prompt for options when they don't exist yet.
 * Added code to save album upon exit if it has changed.
 *
 * Revision 1.1  1996/02/26 02:23:44  klmcw
 * Initial revision
 *
 *---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
#include <limits.h>
#include <memory.h>
#include <signal.h>
#include <sys/stat.h>

#include "fXPlayMidi.h"
#include "about.h"
#include "album.h"
#include "file.h"
#include "options.h"

/*---------------------------------------------------------------------------*/

/* callbacks for form fmAlbum */
void
brAlbumContents_cb(FL_OBJECT *ob, long data)
{
  /* fill-in code for callback */
}
/*---------------------------------------------------------------------------*/
void
btAlbumPlay_cb(FL_OBJECT *ob, long data)
{
  albumPlay((XPMApp_t *)ob->form->u_vdata);
}
/*---------------------------------------------------------------------------*/
void
btFileSettings_cb(FL_OBJECT *ob, long data)
{
  register int Ln;
  const char *File;
  XPMApp_t *App = (XPMApp_t *)ob->form->u_vdata;

  /* TODO: Initialize Form data with selected file */
  if((Ln = albumLineNumCurr(App)) > 0) {
    char chSize[40];
    struct stat stBuf;

    File = albumLineGet(App, Ln);

    fl_set_object_label(App->FileSet->txAlbum, albumCurrentGet());
    fl_set_object_label(App->FileSet->txFile, File);

    memset(chSize, '\0', sizeof(chSize));
    if(stat(File, &stBuf) < 0) strcpy(chSize, "Could Not Stat");
    else                       sprintf(chSize, "%ld bytes", (long)stBuf.st_size);

    fl_set_object_label(App->FileSet->txSize, chSize);
    fl_show_form(App->FileSet->fmFileSettings,FL_PLACE_CENTER,FL_FULLBORDER,
                 "fXPlayMidi File Settings");
  } else
    fl_show_alert("Select a file first!", "", "", 1);
}
/*---------------------------------------------------------------------------*/
void
btFileAdd_cb(FL_OBJECT *ob, long data)
{
  static char chFileNm[_POSIX_PATH_MAX+1];
  XPMApp_t *App = (XPMApp_t *)ob->form->u_vdata;

  memset(chFileNm, '\0', sizeof(chFileNm));

  if(fl_show_fselector("XPlayMidi File Add", optionsDirGet(), "*.mid", NULL) != NULL) {
    sprintf(chFileNm, "%s/%s", fl_get_directory(), fl_get_filename());
    optionsDirSet(fl_get_directory());

    albumFileAdd(App, chFileNm);
  }
}
/*---------------------------------------------------------------------------*/
void
btFileRemove_cb(FL_OBJECT *ob, long data)
{
  register int Ln;
  XPMApp_t *App = (XPMApp_t *)ob->form->u_vdata;

  if((Ln = albumLineNumCurr(App)) > 0)
    albumFileRemove(App, Ln);
  else
    fl_show_alert("Select a file to remove first!", "", "", 1);
}
/*---------------------------------------------------------------------------*/
void
btExit_cb(FL_OBJECT *ob, long data)
{
  XPMApp_t *App = (XPMApp_t *)ob->form->u_vdata;

  if(App->fmFirst != ob->form) {
    fl_winhide(ob->form->window);
  } else if(fileIsPlaying()) {
    if(fl_show_question("Program Exit: Still Playing! Are You Sure ?", 1)) {
      btAlbumPlay_cb(ob, 0L);	/* Perform stop action */

      optionsWrite(ob->form->u_vdata);
      exit(0);
    }
  } else {
    optionsWrite(ob->form->u_vdata);
    exit(0);
  }
}
/*---------------------------------------------------------------------------*/
void
btAlbumLoad_cb(FL_OBJECT *ob, long data)
{
  XPMApp_t *App = (XPMApp_t *)ob->form->u_vdata;

  albumSelect(App, 1);
  fl_set_input(App->Album->inAlbum, albumCurrentGet());
}
/*---------------------------------------------------------------------------*/
void
inAlbum_cb(FL_OBJECT *ob, long data)
{
  const char *Alb, *Album = fl_get_input(ob);
  char Curr[_POSIX_PATH_MAX+1];

  memset(Curr, '\0', sizeof(Curr));
  if(((Alb = albumCurrentGet()) != NULL) && *Alb) {
    strcpy(Curr, Alb);

    if(!albumRead((XPMApp_t *)ob->form->u_vdata, Album))
      optionsAlbumSet(Album);
    else
      fl_set_input(ob, Curr);
  } else
    /* First time -- no valid album */
    albumCurrentSet(Album);
}
/*---------------------------------------------------------------------------*/
void
mnAppOptions_cb(FL_OBJECT *ob, long data)
{
  optionsSelect((XPMApp_t *)ob->form->u_vdata);
}
/*---------------------------------------------------------------------------*/
void
mnAbout_cb(FL_OBJECT *ob, long data)
{
  static int firstTime = 1;
  XPMApp_t *App = (XPMApp_t*)ob->form->u_vdata;

  if(firstTime) { firstTime = 0; aboutFormDefault(App); }
  aboutShow(App);
}
/*---------------------------------------------------------------------------*/
